﻿using FaragostarWebApiTest.Authservice;
using FaragostarWebApiTest.Customerservice;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace FaragostarWebApiTest
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void btnCreateLetter_Click(object sender, EventArgs e)
        {
            LetterDetailModel letterDetailModel;

            using (var customerServiceClient = new CustomerServiceClient())
            using (var authServiceClient = new AuthServiceClient())
            {
                const string username = "Admin";

                var userModel = new CredentialModel
                {
                    Username = username,
                    Password = "1"
                };

                var applicationGuid = new Guid("C22D69E7-6595-42FC-8DE6-E7781EBAFBF0");

                var ticketModel = authServiceClient.SignIn(applicationGuid, userModel);

                var ticket = ticketModel.SecureTicketId;
                var employeePositionModel = customerServiceClient.GetUserEmployeePosition(ticket, username);

                var defaultEmployeePosition = employeePositionModel.FirstOrDefault(emp => emp.IsDefault);

                var employeePositionCode = defaultEmployeePosition.EmployeePositionCode;

                var employeePositionSignature = customerServiceClient.GetEmployeePositionSignature(ticket, employeePositionCode, null);

                var employeePositionSecretariat = customerServiceClient.GetAllSecretariatToSecretariatFormat(ticket, employeePositionCode, null);

                letterDetailModel = new LetterDetailModel
                {
                    Letter = new LetterModel
                    {
                        ContactNameSender = defaultEmployeePosition.FullName,
                        ContactPositionIdSender = employeePositionModel.FirstOrDefault(emp => emp.IsDefault)?.EmployeePositionId,
                        OrganizationIdSender = defaultEmployeePosition.OrganizationId,
                        EmployeePositionIdSender = employeePositionModel.First().EmployeePositionId,
                        EmployeeIdCreator = defaultEmployeePosition.EmployeeId,
                        EmployeePositionSignatureId = employeePositionSignature.FirstOrDefault()?.EmployeePositionSignatureId,
                        SecretariatId = employeePositionSecretariat.FirstOrDefault()?.SecretariatId,
                        SecretariatFormatId = employeePositionSecretariat.FirstOrDefault()?.SecretariatFormatId,
                        CreateDate = DateTime.Now,
                        LetterDate = DateTime.Now,
                        Description = LetterDescriptionTxt.Text,
                        Subject = LetterTitleTxt.Text,
                        LetterSenderCode = employeePositionModel.First().EmployeePositionId.ToString(),
                        LetterDraftTypeKind = LetterDraftTypeKinds.WebEditor,
                        InOutTypeKind = LetterInOutTypeKinds.Indoor,
                        ReplyToCreator = false,
                        SecretariatToSecretariatFormatId = employeePositionSecretariat.FirstOrDefault()?.SecretariatToSecretariatFormatId,
                        EmployeePositionSignerName = defaultEmployeePosition.DepartmentName,
                        ConfidentialTypeId = 1,
                        LastModifiedDate = DateTime.Now,
                        LetterBodyCount = 1,
                        IsLock = true
                    },
                    SyncBodies = true,
                    SyncFirstReceiver = true,
                    FirstReceiver = new LetterReceiverModel[]
                    {
                        new LetterReceiverModel
                        {
                           
                            EmployeePositionId = 3, //ک
                            CopyTypeKind = ReferCopyTypeKinds.Original
                        }
                    }
                };

              
                var bodyFilePath = attachmentFileDialog.FileName;
                var bytes = File.ReadAllBytes(bodyFilePath);
                var fileInfo = new FileInfo(bodyFilePath);

                letterDetailModel.Bodies = new LetterBodyModel[]
                {
                    new LetterBodyModel
                    {
                        FileExtension = fileInfo.Extension,
                        FileName = fileInfo.Name,
                        FileLength = int.Parse(fileInfo.Length.ToString()),
                        FileImage = bytes,
                        PageNumber = 1
                    }
                };

               
                customerServiceClient.SendLetter(ticket, employeePositionCode, letterDetailModel, false, false);

                var ticketId = ticketModel.SecureTicketId;

                MessageBox.Show("Letter created and sent ");
            }
        }

        private void btnSelectAttachment_Click(object sender, EventArgs e)
        {
            attachmentFileDialog.ShowDialog();
        }

        private void Form1_Load(object sender, EventArgs e)
        {

        }
    }
}